
class ExampleEmail():

    def show(self):
        return """subject=Hello
body=World!

Also on
more lines"""


class ExampleConfiguration():

    def show(self):
        return """sender=test@gmail.com
password=example app password"""
